@@ -9,5 +9,5 @@ class YamlHandler(BaseHandler):
     def load(self, data):
         return yaml.load(data)
 
-    def dump(self, data):
-        return yaml.dump(data)
+    def dump(self, data, **kwargs):
+        return yaml.dump(data, **kwargs)
